@@ -51,6 +51,7 @@
 #define FM_ACTION_PASTE_FILES_INTO "Paste Files Into"
 #define FM_ACTION_LOCATION_PASTE_FILES_INTO "LocationPasteFilesInto"
 #define FM_ACTION_NEW_LAUNCHER "New Launcher"
+#define FM_ACTION_NEW_LAUNCHER_DESKTOP "New Launcher Desktop"
 #define FM_ACTION_RENAME "Rename"
 #define FM_ACTION_DUPLICATE "Duplicate"
 #define FM_ACTION_CREATE_LINK "Create Link"
@@ -58,8 +59,11 @@
 #define FM_ACTION_INVERT_SELECTION "Invert Selection"
 #define FM_ACTION_SELECT_PATTERN "Select Pattern"
 #define FM_ACTION_TRASH "Trash"
+#define FM_ACTION_TRASH2 "Trash2"
+#define FM_ACTION_TRASH3 "Trash3"
 #define FM_ACTION_LOCATION_TRASH "LocationTrash"
 #define FM_ACTION_DELETE "Delete"
+#define FM_ACTION_DELETE2 "Delete2"
 #define FM_ACTION_LOCATION_DELETE "LocationDelete"
 #define FM_ACTION_RESTORE_FROM_TRASH "Restore From Trash"
 #define FM_ACTION_LOCATION_RESTORE_FROM_TRASH "LocationRestoreFromTrash"
