@@ -32,11 +32,17 @@
 
 G_BEGIN_DECLS
 
-#define NAUTILUS_TYPE_THROBBER		(nautilus_throbber_get_type ())
-#define NAUTILUS_THROBBER(obj)		(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_THROBBER, NautilusThrobber))
-#define NAUTILUS_THROBBER_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_THROBBER, NautilusThrobberClass))
-#define NAUTILUS_IS_THROBBER(obj)	(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_THROBBER))
-#define NAUTILUS_IS_THROBBER_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_THROBBER))
+#define NAUTILUS_TYPE_THROBBER nautilus_throbber_get_type()
+#define NAUTILUS_THROBBER(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_THROBBER, NautilusThrobber))
+#define NAUTILUS_THROBBER_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_THROBBER, NautilusThrobberClass))
+#define NAUTILUS_IS_THROBBER(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_THROBBER))
+#define NAUTILUS_IS_THROBBER_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_THROBBER))
+#define NAUTILUS_THROBBER_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_THROBBER, NautilusThrobberClass))
 
 typedef EphySpinner NautilusThrobber;
 typedef EphySpinnerClass NautilusThrobberClass;
